@@ -38,7 +38,7 @@ TEMP_OFF = -20
 
 TIMEOUT = 5
 
-__VERSION__ = "1.0.3"
+__VERSION__ = "1.0.7.2"
 
 """
 Exception Handlers
@@ -59,7 +59,7 @@ class WiserNotFound(Error):
     pass
 
 
-class WiserNoRoomsFound(Error):
+class WiserNoRoosFound(Error):
     pass
 
 
@@ -88,6 +88,10 @@ class WiserHubTimeoutException(Error):
     pass
 
 
+class WiserNoRoomsFound(Error):
+    pass
+
+
 class wiserHub:
     def __init__(self, hubIP, secret):
         _LOGGER.info("WiserHub API Initialised : Version {}".format(__VERSION__))
@@ -196,7 +200,7 @@ class wiserHub:
                 timeout=TIMEOUT,
             ).content
             responseContent = re.sub(rb"[^\x20-\x7F]+", b"", responseContent)
-            self.WiserNetworkData = json.loads(responseContent)
+            self.wiserNetworkData = json.loads(responseContent)
 
         except requests.Timeout:
             _LOGGER.debug("Connection timed out trying to update from Wiser Hub")
@@ -212,6 +216,7 @@ class wiserHub:
                 raise WiserRESTException("Unknown Error.")
         except requests.ConnectionError:
             _LOGGER.debug("Connection error trying to update from Wiser Hub")
+            raise
         return self.wiserHubData
 
     def getHubData(self):
@@ -225,10 +230,16 @@ class wiserHub:
         return self.wiserHubData
 
     def getWiserHubName(self):
-        return self.wiserNetworkData.get("Station").get("MdnsHostname")
+        try:
+            return self.wiserNetworkData.get("Station").get("MdnsHostname")
+        except:
+            return self.getDevice(0).get("ModelIdentifier")
 
     def getMACAddress(self):
-        return self.wiserNetworkData.get("Station").get("MacAddress")
+        try:
+            return self.wiserNetworkData.get("Station").get("MacAddress")
+        except:
+            return "NO_MAC_FOUND"
 
     def getRooms(self):
         """
@@ -270,7 +281,10 @@ class wiserHub:
 
         """
         self.checkHubData()
-        return self.wiserHubData.get("HotWater")
+        try:
+            return self.wiserHubData.get("HotWater")
+        except:
+            return None
 
     def getHeatingChannels(self):
         """
@@ -348,7 +362,7 @@ class wiserHub:
         """
         If there is no hotwater object then return false
         """
-        if len(self.wiserHubData.get("HotWater")) < 1:
+        if not self.wiserHubData.get("HotWater"):
             return False
 
         return self.wiserHubData.get("HotWater")[0].get("WaterHeatingState")
@@ -784,7 +798,11 @@ class wiserHub:
 
                 if plug.get("id") == smartPlugId:
                     if plug.get("OutputState") is None:
-                        raise WiserNotFound("Unable to get State of smartPlug {}, is it offline?".format(smartPlugId))
+                        raise WiserNotFound(
+                            "Unable to get State of smartPlug {}, is it offline?".format(
+                                smartPlugId
+                            )
+                        )
                     else:
                         return plug.get("ScheduledState")
         # If we get here then the plug was not found
